'' =================================================================================================
''
''   File....... jm_ee_demo.spin
''   Purpose....
''   Author..... Jon "JonnyMac" McPhalen
''               Copyright (C) 2017 Jon McPhalen
''               -- see below for terms of use
''   E-mail..... jon@jonmcphalen.com
''   Started....
''   Updated.... 25 MAR 2017
''
'' =================================================================================================


con { timing }

  _clkmode = xtal1 + pll16x
  _xinfreq = 5_000_000                                          ' use 5MHz crystal

  CLK_FREQ = (_clkmode >> 6) * _xinfreq                         ' system freq as a constant
  MS_001   = CLK_FREQ / 1_000                                   ' ticks in 1ms
  US_001   = CLK_FREQ / 1_000_000                               ' ticks in 1us
                                                                 
                                                                 
con { io pins }                                                  
                                                                   
  RX1  = 31                                                     ' programming / terminal
  TX1  = 30                                                      
                                                                 
  SDA1 = 29                                                     ' eeprom / i2c
  SCL1 = 28                                                      
                                                                 
                                                                 
con                                                              
                                                                 
  EE_BASE = $8000                                       
                                                                 
                                                                 
obj                                                              
                                                                 
' main                                                          ' * master Spin cog
  time : "jm_time_80"                                           '   timing and delays
  prng : "jm_prng"                                              '   pseudo-random number generator
  io   : "jm_io_basic"                                          '   essential io
  ee   : "jm_24xx512"                                           '   eeprom access
  term : "jm_fullduplexserial"                                  ' * serial IO for terminal
                                                                 
' * uses cog when loaded                                         
                                                                 
                                                                 
var                                                              


dat

  TestVal       byte    $3F, $40, $51, $62, $73, $84, $95, $A6
                                                                 
                                                                 
pub main | idx, val                                                        
                                                                 
  setup                                                          
                                                                 
  term.rxflush                                                  ' clear noise from buffer
  term.rx                                                       ' wait for termina open & keypress     
                                                                 
  term.tx(term#CLS)
  term.str(string("Writing to EEPROM", 13, "--> "))

  repeat idx from 0 to 7
    term.hex(TestVal[idx], 2)
    term.tx(" ")
    ee.wr_byte(EE_BASE+idx, TestVal[idx])

  repeat 2
    term.tx(13)
    
  term.str(string("Read from EEPROM", 13, "<-- "))
  repeat idx from 0 to 7
    val := ee.rd_byte(EE_BASE+idx)   
    term.hex(val, 2)
    term.tx(" ")
     
  repeat                                                         
    waitcnt(0)                                                   
                                                                 
                                                                 
pub setup                                                        
                                                                 
'' Setup IO and objects for application                          
                                                                 
  time.start                                                    ' setup timing & delays
                                                                 
  prng.seed(-cnt, -cnt ~> 2, $EA7_BEEF, cnt <- 2, cnt)          ' seed randomizer
                                                                 
  io.start(0, 0)                                                ' clear all pins (master cog)

  ee.start(%000)                                                ' boot eeprom
                                                                 
  term.start(RX1, TX1, %0000, 115_200)                          ' start serial for terminal
                                                                 

                                                             
dat { license }

  Copyright   byte      "Copyright (C) 2017 Jon McPhalen", 0                                                 

  
{{

  Copyright (C) 2017 Jon McPhalen

  Terms of Use: MIT License

  Permission is hereby granted, free of charge, to any person obtaining a copy of this
  software and associated documentation files (the "Software"), to deal in the Software
  without restriction, including without limitation the rights to use, copy, modify,
  merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
  permit persons to whom the Software is furnished to do so, subject to the following
  conditions:

  The above copyright notice and this permission notice shall be included in all copies
  or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
  PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
  CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
  OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

}}